#!/usr/bin/sh

# Copyright © 2024, Oracle and/or its affiliates.  All rights reserved.
# Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/

config_file=/etc/oci-fss-utils.d/config.json

ca_file=$(jq -r '.caFile' $config_file)
if [ "$ca_file" == "" ]; then
   echo "Failed to find ca_file in json file"
   exit 3
fi

bundle_rotation_time=$(jq '.bundleRotationTime' $config_file)
if [ "$bundle_rotation_time" == "" ]; then
   echo "Failed to find switch for generating bundle in json file"
   exit 5
fi

local_ip="$1"
target_ip="$2"
srcport="$3"
    
# This script gets executed during RPM upgrades and the older
# systemd service unit file won't have the FIPS option. So,
# make sure a default value is assigned.
fips="0"
if [ -n "$4" ]; then
    fips="$4"
fi

cname_arg=""
if [ -n "$5" ]; then
  echo "Using non-standard cname: $5"
  cname_arg="-O $5"
fi

prefsrc=$(/sbin/ip -j route get $target_ip | jq -r ".[].prefsrc") 
local_ip=$(echo $local_ip | tr -d "[]")

exec /bin/oci-fss-forwarder \
    -n ns1 \
    --local-ip $local_ip \
    --target-ip $target_ip \
    --prefsrc $prefsrc \
    -F $fips \
    -C $ca_file \
    $cname_arg
