#!/usr/bin/bash

PREFIX_FILE=/etc/oci-fss-utils.d/prefix.txt

new_prefix_file () {
    mkdir -p $(dirname $1)
    if (( 0 == $(cat /proc/sys/net/ipv6/conf/all/disable_ipv6) )) ; then
        local PREFIX=$(printf "fd40:%x:%x:%x::/64" $(( RANDOM % 0xffff )) $(( RANDOM % 0xffff )) $(( RANDOM % 0xffff)))
        echo $PREFIX > $1
    else
        echo 192.168.255.0/24 > $1
    fi
    echo "Created new prefix file, \"$1\"..."
}

if test -e $PREFIX_FILE ; then
    echo "Using existing prefix file \"$PREFIX_FILE\"..."
else
    new_prefix_file $PREFIX_FILE
fi

PREFIX=$(cat $PREFIX_FILE)
if ! oci-fss-validate-cidr $PREFIX &>/dev/null ; then
    echo "ERROR: Invalid prefix in $PREFIX_FILE..." 1>&2
    new_prefix_file $PREFIX_FILE
fi

if (( 1 == $(cat /proc/sys/net/ipv6/conf/all/disable_ipv6) )) ; then
    echo
    echo WARNING!!!
    echo WARNING!!!    This host has IPv6 disabled.    A /24 will be used from a private
    echo WARNING!!!    IPv4 address range for nfs-client to connect to the TLS forwarder.
    echo WARNING!!!    This could conflict with future or existing IPv4 subnets to which
    echo WARNING!!!    this host connects.
    echo WARNING!!!
    echo WARNING!!!    Enable IPv6 to use an IPv6 ULA address to avoid such conflicts.
    echo WARNING!!!
fi

echo
echo Using $(cat $PREFIX_FILE) to communicate with TLS forwarder.
echo Edit $PREFIX_FILE to customize oci-fss-utils network prefix.
echo
